
/**
 * TestDispatcher.java
 *
 * $Id: TestDispatcher.java 1.1 2001/03/04 13:49:05 murata Exp $
 *
 * Created: Mon Feb 26 00:04:35 2001
 *
 * @author <a href="mailto:mura034@attglobal.net">MURATA Makoto (FAMILY Given)</a>
 * @version
 */

package org.iso_relax.dispatcher;

import javax.xml.parsers.*;
import org.xml.sax.*;
import org.xml.sax.helpers.*;

import java.util.*;
import java.io.*;

public class TestDispatcher extends DefaultDispatcher{

    public TestDispatcher (){

    }

    public DefaultVerifier createHandler(String uri) {
	return new TestVerifier(uri);
    }

    private static String convertToFileURL(String filename) {
        // On JDK 1.2 and later, simplify this to:
        // "path = file.toURL().toString()".
        String path = new File(filename).getAbsolutePath();
        if (File.separatorChar != '/') {
            path = path.replace(File.separatorChar, '/');
        }
        if (!path.startsWith("/")) {
            path = "/" + path;
        }
        return "file:" + path;
    }


    private static void usage() {
        System.err.println("Usage: java org.iso_relax.dispatcher.TestDispatcher <filename>");
        System.exit(1);
    }

    static public void main(String[] args) {
        String filename = null;
        boolean validation = true;

        // Parse arguments
        for (int i = 0; i < args.length; i++) {

	    if (args[i].equals("-v"))
		validation= true;
	    else if (args[i].equals("-n"))
		validation=false;
	    else {
		filename = args[i];

		// Must be last arg
		if (i != args.length - 1) {
		    usage();
		}
	    }
        }
        if (filename == null) {
            usage();
        }

        SAXParserFactory spf = SAXParserFactory.newInstance();
        spf.setValidating(validation);

        XMLReader xmlReader = null;
        try {

            SAXParser saxParser = spf.newSAXParser();

            xmlReader = saxParser.getXMLReader();
        } catch (Exception ex) {
            System.err.println(ex);
            System.exit(1);
        }

	TestDispatcher td = new TestDispatcher();

        xmlReader.setContentHandler(td);

        xmlReader.setErrorHandler(td);

        try {
            xmlReader.parse(convertToFileURL(filename));
        } catch (SAXException se) {
            System.err.println(se.getMessage());
            System.exit(1);
        } catch (IOException ioe) {
            System.err.println(ioe);
            System.exit(1);
        }
    }

    private String getParseExceptionInfo(SAXParseException spe) {
	String systemId = spe.getSystemId();
	if (systemId == null) {
	    systemId = "null";
	}
	String info = "URI=" + systemId +
	    " Line=" + spe.getLineNumber() +
	    ": " + spe.getMessage();
	return info;
    }

    public void warning(SAXParseException spe) throws SAXException {
	System.err.println("Warning: " + getParseExceptionInfo(spe));
    }
        
    public void error(SAXParseException spe) throws SAXException {
	System.err.println("Error: " + getParseExceptionInfo(spe));
    }

    public void fatalError(SAXParseException spe) throws SAXException {
	String message = "Fatal Error: " + getParseExceptionInfo(spe);
	throw new SAXException(message);
    }


}// TestDispatcher
